@option "GRHD" struct Parameters_GRHD <: dg1d.AbstractParameters

  "Time stepping algorithm, choose one out of LSERK, RK4, SSPRK3, ..."
  equation_of_state::AbstractParameters_EquationOfState = Parameters_Polytrope()

  """
  Artificial atmosphere relative amplitude
  Used to determine atmosphere rest-mass density from maximum of rest-mass density of initial data
  according to
    factor * max(rho) = atmosphere_rho.
  """
  factor::Float64 = 1e-8

  """
  Artificial atmosphere activation threshold
  Atmosphere treatment is employed if max(rho) < threshold * atmosphere_rho.
  """
  threshold::Float64 = 100
end


function sanitize(prms::Parameters_GRHD)
  sanitize(prms.equation_of_state)
  @assert prms.factor > 0 "'factor' must be positive!"
  @assert prms.threshold > 0 "'threshold' must be positive!"
end


# @option "TOV" struct Parameters_TOV <: dg1d.AbstractParameters
#   "Initial data filename"
#   initialdata_filename = ""
#   "Maximum domain extension"
#   Rmax::Float64 = 12
#   "Mirror simulation domain across origin"
#   mirror::Bool = true
#   # "High resolution shock capturing technique"
#   # hrsc::Union{Bernstein} = Parameters_Bernstein()
#   "General relativistic hydrodynamics model"
#   grhd::Parameters_GRHD = Parameters_GRHD()
#   "Time evolution"
#   evolution::Parameters_Evolution = Parameters_Evolution()
# end
#
#
# function sanitize(prms::Parameters_TOV)
#   @assert ispath(prms.initialdata_filename) "Could not locate initial data file '$(prms.id_filename)'!"
#   @assert Rmax > 0 "'Rmax' must be positive!"
#   sanitize(prms.hrsc)
#   sanitize(prms.grhd)
#   sanitize(prms.evolution)
# end
