abstract type AbstractParameters end

dg1d.@option "ParametersA" struct DummyParametersA <: dg1d.AbstractParameters
  "Parameter a"
  a::Int64 = 5
  "Parameter b"
  b::Float64 = 2.4
  "Parameter c"
  c::String = "method c"
end

function sanitize(prms::DummyParametersA)
  @assert prms.a > 0 && prms.a < 6
  @assert prms.b > 1.3
  @assert prms.c in [ "method c", "method cc", "method ccc" ]
end

dg1d.@option "ParametersB" struct DummyParametersB <: dg1d.AbstractParameters
  "Parameters A"
  prmsA::DummyParametersA = DummyParametersA(a = 3, b = 3.4)
end

function sanitize(prms::DummyParametersB)
  sanitize(prms.prmsA)
end

@testset "Parameters" begin

@testset "Sanitizing" begin

  # sane values
  prmsA = DummyParametersA()
  sanitize(prmsA)

  # insane values
  @test_throws AssertionError sanitize(DummyParametersA(a = -1))
  @test_throws AssertionError sanitize(DummyParametersA(b = 0.0))
  @test_throws AssertionError sanitize(DummyParametersA(c = "method xyz"))

  # sane values nested parameters
  prmsB = DummyParametersB()
  sanitize(prmsB)

  # insane values nested parameters
  prmsA = DummyParametersA(a = -1)
  prmsB = DummyParametersB(prmsA=prmsA)
  @test_throws AssertionError sanitize(prmsB)

end

end
